init_memory

Function init_memory 

pub fn init_memory() -> AddressSpace
Initialize the memory allocator.

regions - The memory node module of device tree codegen file.

Returns an error if the memory allocator could not be initialized.