pub fn init_memory() -> AddressSpaceExpand description
Initialize the memory allocator.
regions - The memory node module of device tree codegen file.
Returns an error if the memory allocator could not be initialized.
pub fn init_memory() -> AddressSpaceInitialize the memory allocator.
regions - The memory node module of device tree codegen file.
Returns an error if the memory allocator could not be initialized.